@@ -1,3 +1,3 @@
-from .algo import test_algo
+from .algo import test_algo, test_package
 from .metric import test_metric
 from .tabular import load_tabular_data
\ No newline at end of file
