@@ -105,8 +105,8 @@ def test_tabular_algo(algo, output_dir, timeout, nan_fraction):
     model.fit(timeout, metric, X, y, X_metatypes, y_metatypes, X_unlabelled = X)
     fit_seconds = time.time() - t_start
 
-    if fit_seconds > timeout + 10:
-        raise TestError('timeout significantly exceeded')
+    if fit_seconds > timeout:
+        raise TestError('timeout exceeded')
 
     test_tabular_predictor(model, output_dir, X, y)
 
